# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetLbIpsResult',
    'AwaitableGetLbIpsResult',
    'get_lb_ips',
    'get_lb_ips_output',
]

warnings.warn("""scaleway.index/getlbips.getLbIps has been deprecated in favor of scaleway.loadbalancers/getips.getIps""", DeprecationWarning)

@pulumi.output_type
class GetLbIpsResult:
    """
    A collection of values returned by getLbIps.
    """
    def __init__(__self__, id=None, ip_cidr_range=None, ip_type=None, ips=None, organization_id=None, project_id=None, tags=None, zone=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip_cidr_range and not isinstance(ip_cidr_range, str):
            raise TypeError("Expected argument 'ip_cidr_range' to be a str")
        pulumi.set(__self__, "ip_cidr_range", ip_cidr_range)
        if ip_type and not isinstance(ip_type, str):
            raise TypeError("Expected argument 'ip_type' to be a str")
        pulumi.set(__self__, "ip_type", ip_type)
        if ips and not isinstance(ips, list):
            raise TypeError("Expected argument 'ips' to be a list")
        pulumi.set(__self__, "ips", ips)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if zone and not isinstance(zone, str):
            raise TypeError("Expected argument 'zone' to be a str")
        pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="ipCidrRange")
    def ip_cidr_range(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "ip_cidr_range")

    @_builtins.property
    @pulumi.getter(name="ipType")
    def ip_type(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "ip_type")

    @_builtins.property
    @pulumi.getter
    def ips(self) -> Sequence['outputs.GetLbIpsIpResult']:
        """
        List of retrieved IPs
        """
        return pulumi.get(self, "ips")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> _builtins.str:
        """
        The ID of the Organization the Load Balancer is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        The ID of the Project the Load Balancer is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Sequence[_builtins.str]]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[_builtins.str]:
        """
        The zone of the Load Balancer.
        """
        return pulumi.get(self, "zone")


class AwaitableGetLbIpsResult(GetLbIpsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLbIpsResult(
            id=self.id,
            ip_cidr_range=self.ip_cidr_range,
            ip_type=self.ip_type,
            ips=self.ips,
            organization_id=self.organization_id,
            project_id=self.project_id,
            tags=self.tags,
            zone=self.zone)


def get_lb_ips(ip_cidr_range: Optional[_builtins.str] = None,
               ip_type: Optional[_builtins.str] = None,
               project_id: Optional[_builtins.str] = None,
               tags: Optional[Sequence[_builtins.str]] = None,
               zone: Optional[_builtins.str] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLbIpsResult:
    """
    Gets information about multiple Load Balancer IP addresses.

    For more information, see the [main documentation](https://www.scaleway.com/en/docs/load-balancer/how-to/create-manage-flex-ips/) or [API documentation](https://www.scaleway.com/en/developers/api/load-balancer/zoned-api/#path-ip-addresses-list-ip-addresses).


    :param _builtins.str ip_cidr_range: The IP CIDR range to filter for. IPs within a matching CIDR block are listed.
    :param _builtins.str ip_type: The IP type used as a filter.
    :param _builtins.str project_id: The ID of the Project the Load Balancer is associated with.
    :param Sequence[_builtins.str] tags: List of tags used as filter. IPs with these exact tags are listed.
    :param _builtins.str zone: `zone`) The zone in which the IPs exist.
    """
    pulumi.log.warn("""get_lb_ips is deprecated: scaleway.index/getlbips.getLbIps has been deprecated in favor of scaleway.loadbalancers/getips.getIps""")
    __args__ = dict()
    __args__['ipCidrRange'] = ip_cidr_range
    __args__['ipType'] = ip_type
    __args__['projectId'] = project_id
    __args__['tags'] = tags
    __args__['zone'] = zone
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:index/getLbIps:getLbIps', __args__, opts=opts, typ=GetLbIpsResult).value

    return AwaitableGetLbIpsResult(
        id=pulumi.get(__ret__, 'id'),
        ip_cidr_range=pulumi.get(__ret__, 'ip_cidr_range'),
        ip_type=pulumi.get(__ret__, 'ip_type'),
        ips=pulumi.get(__ret__, 'ips'),
        organization_id=pulumi.get(__ret__, 'organization_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'),
        zone=pulumi.get(__ret__, 'zone'))
def get_lb_ips_output(ip_cidr_range: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      ip_type: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      tags: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                      zone: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLbIpsResult]:
    """
    Gets information about multiple Load Balancer IP addresses.

    For more information, see the [main documentation](https://www.scaleway.com/en/docs/load-balancer/how-to/create-manage-flex-ips/) or [API documentation](https://www.scaleway.com/en/developers/api/load-balancer/zoned-api/#path-ip-addresses-list-ip-addresses).


    :param _builtins.str ip_cidr_range: The IP CIDR range to filter for. IPs within a matching CIDR block are listed.
    :param _builtins.str ip_type: The IP type used as a filter.
    :param _builtins.str project_id: The ID of the Project the Load Balancer is associated with.
    :param Sequence[_builtins.str] tags: List of tags used as filter. IPs with these exact tags are listed.
    :param _builtins.str zone: `zone`) The zone in which the IPs exist.
    """
    pulumi.log.warn("""get_lb_ips is deprecated: scaleway.index/getlbips.getLbIps has been deprecated in favor of scaleway.loadbalancers/getips.getIps""")
    __args__ = dict()
    __args__['ipCidrRange'] = ip_cidr_range
    __args__['ipType'] = ip_type
    __args__['projectId'] = project_id
    __args__['tags'] = tags
    __args__['zone'] = zone
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:index/getLbIps:getLbIps', __args__, opts=opts, typ=GetLbIpsResult)
    return __ret__.apply(lambda __response__: GetLbIpsResult(
        id=pulumi.get(__response__, 'id'),
        ip_cidr_range=pulumi.get(__response__, 'ip_cidr_range'),
        ip_type=pulumi.get(__response__, 'ip_type'),
        ips=pulumi.get(__response__, 'ips'),
        organization_id=pulumi.get(__response__, 'organization_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags'),
        zone=pulumi.get(__response__, 'zone')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SnsCredentialsPermissionsArgs',
    'SnsCredentialsPermissionsArgsDict',
    'SqsCredentialsPermissionsArgs',
    'SqsCredentialsPermissionsArgsDict',
    'SqsQueueDeadLetterQueueArgs',
    'SqsQueueDeadLetterQueueArgsDict',
]

MYPY = False

if not MYPY:
    class SnsCredentialsPermissionsArgsDict(TypedDict):
        can_manage: NotRequired[pulumi.Input[_builtins.bool]]
        """
        . Defines whether the user can manage the associated resource(s).
        """
        can_publish: NotRequired[pulumi.Input[_builtins.bool]]
        """
        . Defines whether the user can publish messages to the service.
        """
        can_receive: NotRequired[pulumi.Input[_builtins.bool]]
        """
        . Defines whether the user can receive messages from the service.
        """
elif False:
    SnsCredentialsPermissionsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SnsCredentialsPermissionsArgs:
    def __init__(__self__, *,
                 can_manage: Optional[pulumi.Input[_builtins.bool]] = None,
                 can_publish: Optional[pulumi.Input[_builtins.bool]] = None,
                 can_receive: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        :param pulumi.Input[_builtins.bool] can_manage: . Defines whether the user can manage the associated resource(s).
        :param pulumi.Input[_builtins.bool] can_publish: . Defines whether the user can publish messages to the service.
        :param pulumi.Input[_builtins.bool] can_receive: . Defines whether the user can receive messages from the service.
        """
        if can_manage is not None:
            pulumi.set(__self__, "can_manage", can_manage)
        if can_publish is not None:
            pulumi.set(__self__, "can_publish", can_publish)
        if can_receive is not None:
            pulumi.set(__self__, "can_receive", can_receive)

    @_builtins.property
    @pulumi.getter(name="canManage")
    def can_manage(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        . Defines whether the user can manage the associated resource(s).
        """
        return pulumi.get(self, "can_manage")

    @can_manage.setter
    def can_manage(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "can_manage", value)

    @_builtins.property
    @pulumi.getter(name="canPublish")
    def can_publish(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        . Defines whether the user can publish messages to the service.
        """
        return pulumi.get(self, "can_publish")

    @can_publish.setter
    def can_publish(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "can_publish", value)

    @_builtins.property
    @pulumi.getter(name="canReceive")
    def can_receive(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        . Defines whether the user can receive messages from the service.
        """
        return pulumi.get(self, "can_receive")

    @can_receive.setter
    def can_receive(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "can_receive", value)


if not MYPY:
    class SqsCredentialsPermissionsArgsDict(TypedDict):
        can_manage: NotRequired[pulumi.Input[_builtins.bool]]
        """
        . Defines whether the user can manage the associated resource(s).
        """
        can_publish: NotRequired[pulumi.Input[_builtins.bool]]
        """
        . Defines whether the user can publish messages to the service.
        """
        can_receive: NotRequired[pulumi.Input[_builtins.bool]]
        """
        . Defines whether the user can receive messages from the service.
        """
elif False:
    SqsCredentialsPermissionsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SqsCredentialsPermissionsArgs:
    def __init__(__self__, *,
                 can_manage: Optional[pulumi.Input[_builtins.bool]] = None,
                 can_publish: Optional[pulumi.Input[_builtins.bool]] = None,
                 can_receive: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        :param pulumi.Input[_builtins.bool] can_manage: . Defines whether the user can manage the associated resource(s).
        :param pulumi.Input[_builtins.bool] can_publish: . Defines whether the user can publish messages to the service.
        :param pulumi.Input[_builtins.bool] can_receive: . Defines whether the user can receive messages from the service.
        """
        if can_manage is not None:
            pulumi.set(__self__, "can_manage", can_manage)
        if can_publish is not None:
            pulumi.set(__self__, "can_publish", can_publish)
        if can_receive is not None:
            pulumi.set(__self__, "can_receive", can_receive)

    @_builtins.property
    @pulumi.getter(name="canManage")
    def can_manage(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        . Defines whether the user can manage the associated resource(s).
        """
        return pulumi.get(self, "can_manage")

    @can_manage.setter
    def can_manage(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "can_manage", value)

    @_builtins.property
    @pulumi.getter(name="canPublish")
    def can_publish(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        . Defines whether the user can publish messages to the service.
        """
        return pulumi.get(self, "can_publish")

    @can_publish.setter
    def can_publish(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "can_publish", value)

    @_builtins.property
    @pulumi.getter(name="canReceive")
    def can_receive(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        . Defines whether the user can receive messages from the service.
        """
        return pulumi.get(self, "can_receive")

    @can_receive.setter
    def can_receive(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "can_receive", value)


if not MYPY:
    class SqsQueueDeadLetterQueueArgsDict(TypedDict):
        id: pulumi.Input[_builtins.str]
        """
        The ID of the queue with format `{region/{project-id}/{queue-name}`
        """
        max_receive_count: pulumi.Input[_builtins.int]
        """
        The number of times a message is delivered to the source queue before being sent to the dead-letter queue. Must be between 1 and 1,000.
        """
elif False:
    SqsQueueDeadLetterQueueArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class SqsQueueDeadLetterQueueArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[_builtins.str],
                 max_receive_count: pulumi.Input[_builtins.int]):
        """
        :param pulumi.Input[_builtins.str] id: The ID of the queue with format `{region/{project-id}/{queue-name}`
        :param pulumi.Input[_builtins.int] max_receive_count: The number of times a message is delivered to the source queue before being sent to the dead-letter queue. Must be between 1 and 1,000.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "max_receive_count", max_receive_count)

    @_builtins.property
    @pulumi.getter
    def id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the queue with format `{region/{project-id}/{queue-name}`
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "id", value)

    @_builtins.property
    @pulumi.getter(name="maxReceiveCount")
    def max_receive_count(self) -> pulumi.Input[_builtins.int]:
        """
        The number of times a message is delivered to the source queue before being sent to the dead-letter queue. Must be between 1 and 1,000.
        """
        return pulumi.get(self, "max_receive_count")

    @max_receive_count.setter
    def max_receive_count(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "max_receive_count", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KeyArgs', 'Key']

@pulumi.input_type
class KeyArgs:
    def __init__(__self__, *,
                 algorithm: pulumi.Input[_builtins.str],
                 usage: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 origin: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rotation_policy: Optional[pulumi.Input['KeyRotationPolicyArgs']] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 unprotected: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a Key resource.
        :param pulumi.Input[_builtins.str] algorithm: – The cryptographic algorithm to use. Valid values depend on the `usage`:
               - For `symmetric_encryption`:
        :param pulumi.Input[_builtins.str] usage: – The usage type of the key. Valid values:
        :param pulumi.Input[_builtins.str] description: – A description for the key.
        :param pulumi.Input[_builtins.str] name: The name of the key.
        :param pulumi.Input[_builtins.str] origin: – The origin of the key. Valid values are:
        :param pulumi.Input[_builtins.str] project_id: – The ID of the project the key belongs to.
               
               **Key Usage and Algorithm (both required):**
        :param pulumi.Input[_builtins.str] region: The region in which to create the key (e.g., `fr-par`).
        :param pulumi.Input['KeyRotationPolicyArgs'] rotation_policy: – Rotation policy for the key:
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: – A list of tags to assign to the key.
        :param pulumi.Input[_builtins.bool] unprotected: – If `true`, the key can be deleted. Defaults to `false` (protected).
        """
        pulumi.set(__self__, "algorithm", algorithm)
        pulumi.set(__self__, "usage", usage)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if origin is not None:
            pulumi.set(__self__, "origin", origin)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if rotation_policy is not None:
            pulumi.set(__self__, "rotation_policy", rotation_policy)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if unprotected is not None:
            pulumi.set(__self__, "unprotected", unprotected)

    @_builtins.property
    @pulumi.getter
    def algorithm(self) -> pulumi.Input[_builtins.str]:
        """
        – The cryptographic algorithm to use. Valid values depend on the `usage`:
        - For `symmetric_encryption`:
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "algorithm", value)

    @_builtins.property
    @pulumi.getter
    def usage(self) -> pulumi.Input[_builtins.str]:
        """
        – The usage type of the key. Valid values:
        """
        return pulumi.get(self, "usage")

    @usage.setter
    def usage(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "usage", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        – A description for the key.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the key.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def origin(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        – The origin of the key. Valid values are:
        """
        return pulumi.get(self, "origin")

    @origin.setter
    def origin(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "origin", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        – The ID of the project the key belongs to.

        **Key Usage and Algorithm (both required):**
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the key (e.g., `fr-par`).
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="rotationPolicy")
    def rotation_policy(self) -> Optional[pulumi.Input['KeyRotationPolicyArgs']]:
        """
        – Rotation policy for the key:
        """
        return pulumi.get(self, "rotation_policy")

    @rotation_policy.setter
    def rotation_policy(self, value: Optional[pulumi.Input['KeyRotationPolicyArgs']]):
        pulumi.set(self, "rotation_policy", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        – A list of tags to assign to the key.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def unprotected(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        – If `true`, the key can be deleted. Defaults to `false` (protected).
        """
        return pulumi.get(self, "unprotected")

    @unprotected.setter
    def unprotected(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "unprotected", value)


@pulumi.input_type
class _KeyState:
    def __init__(__self__, *,
                 algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 locked: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 origin: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protected: Optional[pulumi.Input[_builtins.bool]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rotated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 rotation_count: Optional[pulumi.Input[_builtins.int]] = None,
                 rotation_policy: Optional[pulumi.Input['KeyRotationPolicyArgs']] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 unprotected: Optional[pulumi.Input[_builtins.bool]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Key resources.
        :param pulumi.Input[_builtins.str] algorithm: – The cryptographic algorithm to use. Valid values depend on the `usage`:
               - For `symmetric_encryption`:
        :param pulumi.Input[_builtins.str] created_at: The date and time when the key was created.
        :param pulumi.Input[_builtins.str] description: – A description for the key.
        :param pulumi.Input[_builtins.bool] locked: Whether the key is locked.
        :param pulumi.Input[_builtins.str] name: The name of the key.
        :param pulumi.Input[_builtins.str] origin: – The origin of the key. Valid values are:
        :param pulumi.Input[_builtins.str] project_id: – The ID of the project the key belongs to.
               
               **Key Usage and Algorithm (both required):**
        :param pulumi.Input[_builtins.bool] protected: Whether the key is protected from deletion.
        :param pulumi.Input[_builtins.str] region: The region in which to create the key (e.g., `fr-par`).
        :param pulumi.Input[_builtins.str] rotated_at: The date and time when the key was last rotated.
        :param pulumi.Input[_builtins.int] rotation_count: The number of times the key has been rotated.
        :param pulumi.Input['KeyRotationPolicyArgs'] rotation_policy: – Rotation policy for the key:
        :param pulumi.Input[_builtins.str] state: The state of the key (e.g., `enabled`).
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: – A list of tags to assign to the key.
        :param pulumi.Input[_builtins.bool] unprotected: – If `true`, the key can be deleted. Defaults to `false` (protected).
        :param pulumi.Input[_builtins.str] updated_at: The date and time when the key was last updated.
        :param pulumi.Input[_builtins.str] usage: – The usage type of the key. Valid values:
        """
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if locked is not None:
            pulumi.set(__self__, "locked", locked)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if origin is not None:
            pulumi.set(__self__, "origin", origin)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if protected is not None:
            pulumi.set(__self__, "protected", protected)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if rotated_at is not None:
            pulumi.set(__self__, "rotated_at", rotated_at)
        if rotation_count is not None:
            pulumi.set(__self__, "rotation_count", rotation_count)
        if rotation_policy is not None:
            pulumi.set(__self__, "rotation_policy", rotation_policy)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if unprotected is not None:
            pulumi.set(__self__, "unprotected", unprotected)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if usage is not None:
            pulumi.set(__self__, "usage", usage)

    @_builtins.property
    @pulumi.getter
    def algorithm(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        – The cryptographic algorithm to use. Valid values depend on the `usage`:
        - For `symmetric_encryption`:
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "algorithm", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time when the key was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        – A description for the key.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def locked(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the key is locked.
        """
        return pulumi.get(self, "locked")

    @locked.setter
    def locked(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "locked", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the key.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def origin(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        – The origin of the key. Valid values are:
        """
        return pulumi.get(self, "origin")

    @origin.setter
    def origin(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "origin", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        – The ID of the project the key belongs to.

        **Key Usage and Algorithm (both required):**
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def protected(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the key is protected from deletion.
        """
        return pulumi.get(self, "protected")

    @protected.setter
    def protected(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "protected", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The region in which to create the key (e.g., `fr-par`).
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="rotatedAt")
    def rotated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time when the key was last rotated.
        """
        return pulumi.get(self, "rotated_at")

    @rotated_at.setter
    def rotated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rotated_at", value)

    @_builtins.property
    @pulumi.getter(name="rotationCount")
    def rotation_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of times the key has been rotated.
        """
        return pulumi.get(self, "rotation_count")

    @rotation_count.setter
    def rotation_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "rotation_count", value)

    @_builtins.property
    @pulumi.getter(name="rotationPolicy")
    def rotation_policy(self) -> Optional[pulumi.Input['KeyRotationPolicyArgs']]:
        """
        – Rotation policy for the key:
        """
        return pulumi.get(self, "rotation_policy")

    @rotation_policy.setter
    def rotation_policy(self, value: Optional[pulumi.Input['KeyRotationPolicyArgs']]):
        pulumi.set(self, "rotation_policy", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The state of the key (e.g., `enabled`).
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        – A list of tags to assign to the key.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def unprotected(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        – If `true`, the key can be deleted. Defaults to `false` (protected).
        """
        return pulumi.get(self, "unprotected")

    @unprotected.setter
    def unprotected(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "unprotected", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time when the key was last updated.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter
    def usage(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        – The usage type of the key. Valid values:
        """
        return pulumi.get(self, "usage")

    @usage.setter
    def usage(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "usage", value)


@pulumi.type_token("scaleway:keymanager/key:Key")
class Key(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 origin: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rotation_policy: Optional[pulumi.Input[Union['KeyRotationPolicyArgs', 'KeyRotationPolicyArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 unprotected: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a Scaleway Key Manager Key resource.\\
        This resource allows you to create and manage cryptographic keys in Scaleway Key Manager (KMS).

        ## Example Usage

        ### Symmetric Encryption Key

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        symmetric = scaleway.keymanager.Key("symmetric",
            name="my-kms-key",
            region="fr-par",
            project_id="your-project-id",
            usage="symmetric_encryption",
            algorithm="aes_256_gcm",
            description="Key for encrypting secrets",
            tags=[
                "env:prod",
                "kms",
            ],
            unprotected=True,
            rotation_policy={
                "rotation_period": "720h",
            })
        ```

        ### Asymmetric Encryption Key with RSA-4096

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        rsa4096 = scaleway.keymanager.Key("rsa_4096",
            name="rsa-4096-key",
            region="fr-par",
            usage="asymmetric_encryption",
            algorithm="rsa_oaep_4096_sha256",
            description="Key for encrypting large files with RSA-4096",
            unprotected=True)
        ```

        ### Asymmetric Signing Key

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        signing = scaleway.keymanager.Key("signing",
            name="signing-key",
            region="fr-par",
            usage="asymmetric_signing",
            algorithm="rsa_pss_2048_sha256",
            description="Key for signing documents",
            unprotected=True)
        ```

        ## Notes

        - **Protection**: By default, keys are protected and cannot be deleted. To allow deletion, set `unprotected = true` when creating the key.
        - **Rotation Policy**: The `rotation_policy` block allows you to set automatic rotation for your key.
        - **Origin**: The `origin` argument is optional and defaults to `scaleway_kms`. Use `external` if you want to import an external key (see Scaleway documentation for details).
        - **Project and Region**: If not specified, `project_id` and `region` will default to the provider configuration.
        - **Algorithm Validation**: The provider validates that the specified `algorithm` is compatible with the `usage` type at plan time, providing early feedback on configuration errors.

        ## Import

        You can import a key using its ID and region:

        ```sh
        $ pulumi import scaleway:keymanager/key:Key main fr-par/11111111-2222-3333-4444-555555555555
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] algorithm: – The cryptographic algorithm to use. Valid values depend on the `usage`:
               - For `symmetric_encryption`:
        :param pulumi.Input[_builtins.str] description: – A description for the key.
        :param pulumi.Input[_builtins.str] name: The name of the key.
        :param pulumi.Input[_builtins.str] origin: – The origin of the key. Valid values are:
        :param pulumi.Input[_builtins.str] project_id: – The ID of the project the key belongs to.
               
               **Key Usage and Algorithm (both required):**
        :param pulumi.Input[_builtins.str] region: The region in which to create the key (e.g., `fr-par`).
        :param pulumi.Input[Union['KeyRotationPolicyArgs', 'KeyRotationPolicyArgsDict']] rotation_policy: – Rotation policy for the key:
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: – A list of tags to assign to the key.
        :param pulumi.Input[_builtins.bool] unprotected: – If `true`, the key can be deleted. Defaults to `false` (protected).
        :param pulumi.Input[_builtins.str] usage: – The usage type of the key. Valid values:
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Scaleway Key Manager Key resource.\\
        This resource allows you to create and manage cryptographic keys in Scaleway Key Manager (KMS).

        ## Example Usage

        ### Symmetric Encryption Key

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        symmetric = scaleway.keymanager.Key("symmetric",
            name="my-kms-key",
            region="fr-par",
            project_id="your-project-id",
            usage="symmetric_encryption",
            algorithm="aes_256_gcm",
            description="Key for encrypting secrets",
            tags=[
                "env:prod",
                "kms",
            ],
            unprotected=True,
            rotation_policy={
                "rotation_period": "720h",
            })
        ```

        ### Asymmetric Encryption Key with RSA-4096

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        rsa4096 = scaleway.keymanager.Key("rsa_4096",
            name="rsa-4096-key",
            region="fr-par",
            usage="asymmetric_encryption",
            algorithm="rsa_oaep_4096_sha256",
            description="Key for encrypting large files with RSA-4096",
            unprotected=True)
        ```

        ### Asymmetric Signing Key

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        signing = scaleway.keymanager.Key("signing",
            name="signing-key",
            region="fr-par",
            usage="asymmetric_signing",
            algorithm="rsa_pss_2048_sha256",
            description="Key for signing documents",
            unprotected=True)
        ```

        ## Notes

        - **Protection**: By default, keys are protected and cannot be deleted. To allow deletion, set `unprotected = true` when creating the key.
        - **Rotation Policy**: The `rotation_policy` block allows you to set automatic rotation for your key.
        - **Origin**: The `origin` argument is optional and defaults to `scaleway_kms`. Use `external` if you want to import an external key (see Scaleway documentation for details).
        - **Project and Region**: If not specified, `project_id` and `region` will default to the provider configuration.
        - **Algorithm Validation**: The provider validates that the specified `algorithm` is compatible with the `usage` type at plan time, providing early feedback on configuration errors.

        ## Import

        You can import a key using its ID and region:

        ```sh
        $ pulumi import scaleway:keymanager/key:Key main fr-par/11111111-2222-3333-4444-555555555555
        ```

        :param str resource_name: The name of the resource.
        :param KeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 algorithm: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 origin: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 rotation_policy: Optional[pulumi.Input[Union['KeyRotationPolicyArgs', 'KeyRotationPolicyArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 unprotected: Optional[pulumi.Input[_builtins.bool]] = None,
                 usage: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KeyArgs.__new__(KeyArgs)

            if algorithm is None and not opts.urn:
                raise TypeError("Missing required property 'algorithm'")
            __props__.__dict__["algorithm"] = algorithm
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["origin"] = origin
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["rotation_policy"] = rotation_policy
            __props__.__dict__["tags"] = tags
            __props__.__dict__["unprotected"] = unprotected
            if usage is None and not opts.urn:
                raise TypeError("Missing required property 'usage'")
            __props__.__dict__["usage"] = usage
            __props__.__dict__["created_at"] = None
            __props__.__dict__["locked"] = None
            __props__.__dict__["protected"] = None
            __props__.__dict__["rotated_at"] = None
            __props__.__dict__["rotation_count"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["updated_at"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/keyManagerKey:KeyManagerKey")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        super(Key, __self__).__init__(
            'scaleway:keymanager/key:Key',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            algorithm: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            locked: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            origin: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            protected: Optional[pulumi.Input[_builtins.bool]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            rotated_at: Optional[pulumi.Input[_builtins.str]] = None,
            rotation_count: Optional[pulumi.Input[_builtins.int]] = None,
            rotation_policy: Optional[pulumi.Input[Union['KeyRotationPolicyArgs', 'KeyRotationPolicyArgsDict']]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            unprotected: Optional[pulumi.Input[_builtins.bool]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            usage: Optional[pulumi.Input[_builtins.str]] = None) -> 'Key':
        """
        Get an existing Key resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] algorithm: – The cryptographic algorithm to use. Valid values depend on the `usage`:
               - For `symmetric_encryption`:
        :param pulumi.Input[_builtins.str] created_at: The date and time when the key was created.
        :param pulumi.Input[_builtins.str] description: – A description for the key.
        :param pulumi.Input[_builtins.bool] locked: Whether the key is locked.
        :param pulumi.Input[_builtins.str] name: The name of the key.
        :param pulumi.Input[_builtins.str] origin: – The origin of the key. Valid values are:
        :param pulumi.Input[_builtins.str] project_id: – The ID of the project the key belongs to.
               
               **Key Usage and Algorithm (both required):**
        :param pulumi.Input[_builtins.bool] protected: Whether the key is protected from deletion.
        :param pulumi.Input[_builtins.str] region: The region in which to create the key (e.g., `fr-par`).
        :param pulumi.Input[_builtins.str] rotated_at: The date and time when the key was last rotated.
        :param pulumi.Input[_builtins.int] rotation_count: The number of times the key has been rotated.
        :param pulumi.Input[Union['KeyRotationPolicyArgs', 'KeyRotationPolicyArgsDict']] rotation_policy: – Rotation policy for the key:
        :param pulumi.Input[_builtins.str] state: The state of the key (e.g., `enabled`).
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: – A list of tags to assign to the key.
        :param pulumi.Input[_builtins.bool] unprotected: – If `true`, the key can be deleted. Defaults to `false` (protected).
        :param pulumi.Input[_builtins.str] updated_at: The date and time when the key was last updated.
        :param pulumi.Input[_builtins.str] usage: – The usage type of the key. Valid values:
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KeyState.__new__(_KeyState)

        __props__.__dict__["algorithm"] = algorithm
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["locked"] = locked
        __props__.__dict__["name"] = name
        __props__.__dict__["origin"] = origin
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["protected"] = protected
        __props__.__dict__["region"] = region
        __props__.__dict__["rotated_at"] = rotated_at
        __props__.__dict__["rotation_count"] = rotation_count
        __props__.__dict__["rotation_policy"] = rotation_policy
        __props__.__dict__["state"] = state
        __props__.__dict__["tags"] = tags
        __props__.__dict__["unprotected"] = unprotected
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["usage"] = usage
        return Key(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def algorithm(self) -> pulumi.Output[_builtins.str]:
        """
        – The cryptographic algorithm to use. Valid values depend on the `usage`:
        - For `symmetric_encryption`:
        """
        return pulumi.get(self, "algorithm")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time when the key was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        – A description for the key.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def locked(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the key is locked.
        """
        return pulumi.get(self, "locked")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the key.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def origin(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        – The origin of the key. Valid values are:
        """
        return pulumi.get(self, "origin")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        – The ID of the project the key belongs to.

        **Key Usage and Algorithm (both required):**
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def protected(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the key is protected from deletion.
        """
        return pulumi.get(self, "protected")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The region in which to create the key (e.g., `fr-par`).
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="rotatedAt")
    def rotated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time when the key was last rotated.
        """
        return pulumi.get(self, "rotated_at")

    @_builtins.property
    @pulumi.getter(name="rotationCount")
    def rotation_count(self) -> pulumi.Output[_builtins.int]:
        """
        The number of times the key has been rotated.
        """
        return pulumi.get(self, "rotation_count")

    @_builtins.property
    @pulumi.getter(name="rotationPolicy")
    def rotation_policy(self) -> pulumi.Output[Optional['outputs.KeyRotationPolicy']]:
        """
        – Rotation policy for the key:
        """
        return pulumi.get(self, "rotation_policy")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        The state of the key (e.g., `enabled`).
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        – A list of tags to assign to the key.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def unprotected(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        – If `true`, the key can be deleted. Defaults to `false` (protected).
        """
        return pulumi.get(self, "unprotected")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time when the key was last updated.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter
    def usage(self) -> pulumi.Output[_builtins.str]:
        """
        – The usage type of the key. Valid values:
        """
        return pulumi.get(self, "usage")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ConnectionBgpConfigIpv4Args',
    'ConnectionBgpConfigIpv4ArgsDict',
    'ConnectionBgpConfigIpv6Args',
    'ConnectionBgpConfigIpv6ArgsDict',
    'ConnectionBgpSessionIpv4Args',
    'ConnectionBgpSessionIpv4ArgsDict',
    'ConnectionBgpSessionIpv6Args',
    'ConnectionBgpSessionIpv6ArgsDict',
    'ConnectionEspCipherArgs',
    'ConnectionEspCipherArgsDict',
    'ConnectionIkev2CipherArgs',
    'ConnectionIkev2CipherArgsDict',
    'GatewayPublicConfigArgs',
    'GatewayPublicConfigArgsDict',
]

MYPY = False

if not MYPY:
    class ConnectionBgpConfigIpv4ArgsDict(TypedDict):
        routing_policy_id: pulumi.Input[_builtins.str]
        """
        The routing policy ID used for this BGP session.
        """
        peer_private_ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        private_ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
elif False:
    ConnectionBgpConfigIpv4ArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConnectionBgpConfigIpv4Args:
    def __init__(__self__, *,
                 routing_policy_id: pulumi.Input[_builtins.str],
                 peer_private_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 private_ip: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] routing_policy_id: The routing policy ID used for this BGP session.
        :param pulumi.Input[_builtins.str] peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param pulumi.Input[_builtins.str] private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        """
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> pulumi.Input[_builtins.str]:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")

    @routing_policy_id.setter
    def routing_policy_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "routing_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @peer_private_ip.setter
    def peer_private_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "peer_private_ip", value)

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")

    @private_ip.setter
    def private_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_ip", value)


if not MYPY:
    class ConnectionBgpConfigIpv6ArgsDict(TypedDict):
        routing_policy_id: pulumi.Input[_builtins.str]
        """
        The routing policy ID used for this BGP session.
        """
        peer_private_ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        private_ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
elif False:
    ConnectionBgpConfigIpv6ArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConnectionBgpConfigIpv6Args:
    def __init__(__self__, *,
                 routing_policy_id: pulumi.Input[_builtins.str],
                 peer_private_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 private_ip: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] routing_policy_id: The routing policy ID used for this BGP session.
        :param pulumi.Input[_builtins.str] peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param pulumi.Input[_builtins.str] private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        """
        pulumi.set(__self__, "routing_policy_id", routing_policy_id)
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> pulumi.Input[_builtins.str]:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")

    @routing_policy_id.setter
    def routing_policy_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "routing_policy_id", value)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @peer_private_ip.setter
    def peer_private_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "peer_private_ip", value)

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")

    @private_ip.setter
    def private_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_ip", value)


if not MYPY:
    class ConnectionBgpSessionIpv4ArgsDict(TypedDict):
        peer_private_ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        private_ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        routing_policy_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The routing policy ID used for this BGP session.
        """
elif False:
    ConnectionBgpSessionIpv4ArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConnectionBgpSessionIpv4Args:
    def __init__(__self__, *,
                 peer_private_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 private_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 routing_policy_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param pulumi.Input[_builtins.str] private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        :param pulumi.Input[_builtins.str] routing_policy_id: The routing policy ID used for this BGP session.
        """
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)
        if routing_policy_id is not None:
            pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @peer_private_ip.setter
    def peer_private_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "peer_private_ip", value)

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")

    @private_ip.setter
    def private_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_ip", value)

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")

    @routing_policy_id.setter
    def routing_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "routing_policy_id", value)


if not MYPY:
    class ConnectionBgpSessionIpv6ArgsDict(TypedDict):
        peer_private_ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        private_ip: NotRequired[pulumi.Input[_builtins.str]]
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        routing_policy_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The routing policy ID used for this BGP session.
        """
elif False:
    ConnectionBgpSessionIpv6ArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConnectionBgpSessionIpv6Args:
    def __init__(__self__, *,
                 peer_private_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 private_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 routing_policy_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] peer_private_ip: The BGP peer IP on customer side (within the tunnel).
        :param pulumi.Input[_builtins.str] private_ip: The BGP peer IP on Scaleway side (within the tunnel).
        :param pulumi.Input[_builtins.str] routing_policy_id: The routing policy ID used for this BGP session.
        """
        if peer_private_ip is not None:
            pulumi.set(__self__, "peer_private_ip", peer_private_ip)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)
        if routing_policy_id is not None:
            pulumi.set(__self__, "routing_policy_id", routing_policy_id)

    @_builtins.property
    @pulumi.getter(name="peerPrivateIp")
    def peer_private_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The BGP peer IP on customer side (within the tunnel).
        """
        return pulumi.get(self, "peer_private_ip")

    @peer_private_ip.setter
    def peer_private_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "peer_private_ip", value)

    @_builtins.property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The BGP peer IP on Scaleway side (within the tunnel).
        """
        return pulumi.get(self, "private_ip")

    @private_ip.setter
    def private_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_ip", value)

    @_builtins.property
    @pulumi.getter(name="routingPolicyId")
    def routing_policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The routing policy ID used for this BGP session.
        """
        return pulumi.get(self, "routing_policy_id")

    @routing_policy_id.setter
    def routing_policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "routing_policy_id", value)


if not MYPY:
    class ConnectionEspCipherArgsDict(TypedDict):
        encryption: pulumi.Input[_builtins.str]
        """
        The encryption algorithm
        """
        dh_group: NotRequired[pulumi.Input[_builtins.str]]
        """
        The Diffie-Hellman group
        """
        integrity: NotRequired[pulumi.Input[_builtins.str]]
        """
        The integrity/hash algorithm
        """
elif False:
    ConnectionEspCipherArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConnectionEspCipherArgs:
    def __init__(__self__, *,
                 encryption: pulumi.Input[_builtins.str],
                 dh_group: Optional[pulumi.Input[_builtins.str]] = None,
                 integrity: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] encryption: The encryption algorithm
        :param pulumi.Input[_builtins.str] dh_group: The Diffie-Hellman group
        :param pulumi.Input[_builtins.str] integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "encryption", encryption)
        if dh_group is not None:
            pulumi.set(__self__, "dh_group", dh_group)
        if integrity is not None:
            pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> pulumi.Input[_builtins.str]:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @encryption.setter
    def encryption(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "encryption", value)

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @dh_group.setter
    def dh_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dh_group", value)

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")

    @integrity.setter
    def integrity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "integrity", value)


if not MYPY:
    class ConnectionIkev2CipherArgsDict(TypedDict):
        encryption: pulumi.Input[_builtins.str]
        """
        The encryption algorithm
        """
        dh_group: NotRequired[pulumi.Input[_builtins.str]]
        """
        The Diffie-Hellman group
        """
        integrity: NotRequired[pulumi.Input[_builtins.str]]
        """
        The integrity/hash algorithm
        """
elif False:
    ConnectionIkev2CipherArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ConnectionIkev2CipherArgs:
    def __init__(__self__, *,
                 encryption: pulumi.Input[_builtins.str],
                 dh_group: Optional[pulumi.Input[_builtins.str]] = None,
                 integrity: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] encryption: The encryption algorithm
        :param pulumi.Input[_builtins.str] dh_group: The Diffie-Hellman group
        :param pulumi.Input[_builtins.str] integrity: The integrity/hash algorithm
        """
        pulumi.set(__self__, "encryption", encryption)
        if dh_group is not None:
            pulumi.set(__self__, "dh_group", dh_group)
        if integrity is not None:
            pulumi.set(__self__, "integrity", integrity)

    @_builtins.property
    @pulumi.getter
    def encryption(self) -> pulumi.Input[_builtins.str]:
        """
        The encryption algorithm
        """
        return pulumi.get(self, "encryption")

    @encryption.setter
    def encryption(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "encryption", value)

    @_builtins.property
    @pulumi.getter(name="dhGroup")
    def dh_group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Diffie-Hellman group
        """
        return pulumi.get(self, "dh_group")

    @dh_group.setter
    def dh_group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dh_group", value)

    @_builtins.property
    @pulumi.getter
    def integrity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The integrity/hash algorithm
        """
        return pulumi.get(self, "integrity")

    @integrity.setter
    def integrity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "integrity", value)


if not MYPY:
    class GatewayPublicConfigArgsDict(TypedDict):
        ipam_ipv4_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway.
        """
        ipam_ipv6_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway.
        """
elif False:
    GatewayPublicConfigArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GatewayPublicConfigArgs:
    def __init__(__self__, *,
                 ipam_ipv4_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ipam_ipv6_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] ipam_ipv4_id: The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway.
        :param pulumi.Input[_builtins.str] ipam_ipv6_id: The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway.
        """
        if ipam_ipv4_id is not None:
            pulumi.set(__self__, "ipam_ipv4_id", ipam_ipv4_id)
        if ipam_ipv6_id is not None:
            pulumi.set(__self__, "ipam_ipv6_id", ipam_ipv6_id)

    @_builtins.property
    @pulumi.getter(name="ipamIpv4Id")
    def ipam_ipv4_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM IPv4 address to use as the public IP for the VPN gateway.
        """
        return pulumi.get(self, "ipam_ipv4_id")

    @ipam_ipv4_id.setter
    def ipam_ipv4_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_ipv4_id", value)

    @_builtins.property
    @pulumi.getter(name="ipamIpv6Id")
    def ipam_ipv6_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the IPAM IPv6 address to use as the public IP for the VPN gateway.
        """
        return pulumi.get(self, "ipam_ipv6_id")

    @ipam_ipv6_id.setter
    def ipam_ipv6_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ipam_ipv6_id", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['RegistryNamespaceArgs', 'RegistryNamespace']

@pulumi.input_type
class RegistryNamespaceArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_public: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RegistryNamespace resource.
        :param pulumi.Input[_builtins.str] description: The description of the namespace.
        :param pulumi.Input[_builtins.bool] is_public: Whether the images stored in the namespace should be downloadable publicly (docker pull).
        :param pulumi.Input[_builtins.str] name: The unique name of the namespace.
               
               > **Important** Updates to `name` will recreate the namespace.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the namespace is associated with.
        :param pulumi.Input[_builtins.str] region: `region`). The region in which the namespace should be created.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_public is not None:
            pulumi.set(__self__, "is_public", is_public)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the namespace.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the images stored in the namespace should be downloadable publicly (docker pull).
        """
        return pulumi.get(self, "is_public")

    @is_public.setter
    def is_public(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_public", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the namespace.

        > **Important** Updates to `name` will recreate the namespace.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the namespace is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). The region in which the namespace should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


@pulumi.input_type
class _RegistryNamespaceState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                 is_public: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering RegistryNamespace resources.
        :param pulumi.Input[_builtins.str] description: The description of the namespace.
        :param pulumi.Input[_builtins.str] endpoint: Endpoint reachable by Docker.
        :param pulumi.Input[_builtins.bool] is_public: Whether the images stored in the namespace should be downloadable publicly (docker pull).
        :param pulumi.Input[_builtins.str] name: The unique name of the namespace.
               
               > **Important** Updates to `name` will recreate the namespace.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the namespace is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the namespace is associated with.
        :param pulumi.Input[_builtins.str] region: `region`). The region in which the namespace should be created.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if endpoint is not None:
            pulumi.set(__self__, "endpoint", endpoint)
        if is_public is not None:
            pulumi.set(__self__, "is_public", is_public)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the namespace.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Endpoint reachable by Docker.
        """
        return pulumi.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "endpoint", value)

    @_builtins.property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the images stored in the namespace should be downloadable publicly (docker pull).
        """
        return pulumi.get(self, "is_public")

    @is_public.setter
    def is_public(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_public", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the namespace.

        > **Important** Updates to `name` will recreate the namespace.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Organization ID the namespace is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the project the namespace is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `region`). The region in which the namespace should be created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


warnings.warn("""scaleway.index/registrynamespace.RegistryNamespace has been deprecated in favor of scaleway.registry/namespace.Namespace""", DeprecationWarning)


@pulumi.type_token("scaleway:index/registryNamespace:RegistryNamespace")
class RegistryNamespace(pulumi.CustomResource):
    warnings.warn("""scaleway.index/registrynamespace.RegistryNamespace has been deprecated in favor of scaleway.registry/namespace.Namespace""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_public: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates and manages Scaleway Container Registry.
        For more information refer to the [API documentation](https://www.scaleway.com/en/developers/api/registry).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.registry.Namespace("main",
            name="main-cr",
            description="Main container registry",
            is_public=False)
        ```

        ## Import

        Namespaces can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/registryNamespace:RegistryNamespace main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the namespace.
        :param pulumi.Input[_builtins.bool] is_public: Whether the images stored in the namespace should be downloadable publicly (docker pull).
        :param pulumi.Input[_builtins.str] name: The unique name of the namespace.
               
               > **Important** Updates to `name` will recreate the namespace.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the namespace is associated with.
        :param pulumi.Input[_builtins.str] region: `region`). The region in which the namespace should be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[RegistryNamespaceArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates and manages Scaleway Container Registry.
        For more information refer to the [API documentation](https://www.scaleway.com/en/developers/api/registry).

        ## Example Usage

        ### Basic

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.registry.Namespace("main",
            name="main-cr",
            description="Main container registry",
            is_public=False)
        ```

        ## Import

        Namespaces can be imported using the `{region}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/registryNamespace:RegistryNamespace main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param RegistryNamespaceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RegistryNamespaceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_public: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""RegistryNamespace is deprecated: scaleway.index/registrynamespace.RegistryNamespace has been deprecated in favor of scaleway.registry/namespace.Namespace""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RegistryNamespaceArgs.__new__(RegistryNamespaceArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["is_public"] = is_public
            __props__.__dict__["name"] = name
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["region"] = region
            __props__.__dict__["endpoint"] = None
            __props__.__dict__["organization_id"] = None
        super(RegistryNamespace, __self__).__init__(
            'scaleway:index/registryNamespace:RegistryNamespace',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            endpoint: Optional[pulumi.Input[_builtins.str]] = None,
            is_public: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None) -> 'RegistryNamespace':
        """
        Get an existing RegistryNamespace resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: The description of the namespace.
        :param pulumi.Input[_builtins.str] endpoint: Endpoint reachable by Docker.
        :param pulumi.Input[_builtins.bool] is_public: Whether the images stored in the namespace should be downloadable publicly (docker pull).
        :param pulumi.Input[_builtins.str] name: The unique name of the namespace.
               
               > **Important** Updates to `name` will recreate the namespace.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the namespace is associated with.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the project the namespace is associated with.
        :param pulumi.Input[_builtins.str] region: `region`). The region in which the namespace should be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RegistryNamespaceState.__new__(_RegistryNamespaceState)

        __props__.__dict__["description"] = description
        __props__.__dict__["endpoint"] = endpoint
        __props__.__dict__["is_public"] = is_public
        __props__.__dict__["name"] = name
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        return RegistryNamespace(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the namespace.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> pulumi.Output[_builtins.str]:
        """
        Endpoint reachable by Docker.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the images stored in the namespace should be downloadable publicly (docker pull).
        """
        return pulumi.get(self, "is_public")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The unique name of the namespace.

        > **Important** Updates to `name` will recreate the namespace.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Organization ID the namespace is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the project the namespace is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `region`). The region in which the namespace should be created.
        """
        return pulumi.get(self, "region")

